public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-04-24 17:20 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-04-24 17:20 UTC (permalink / raw
  To: gentoo-commits

commit:     be225af8d9aeb6a839f8ff231cbee61d3be45e0f
Author:     Michael Haubenwallner <haubi <AT> gentoo <DOT> org>
AuthorDate: Sun Apr 24 17:18:03 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Apr 24 17:18:03 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=be225af8

shebang check: ignore symlinks that point outside the prefix

As documented in bug #282539, we can have symlinks that point outside
the prefix.  The targets of those files need not to be checked for their
shebang, as they are obviously not under our control.

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

---
 bin/misc-functions.sh |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 59cc9d4..3bf5060 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -800,15 +800,18 @@ install_qa_check_prefix() {
 		IFS=${oldIFS}
 		[[ ${WHITELIST} == *" ${line[0]} "* ]] && continue
 		local fp=${fn#${D}} ; fp=/${fp%/*}
+		# line[0] can be an absolutised path, bug #342929
+		local eprefix=$(canonicalize ${EPREFIX})
 		local rf=${fn}
 		# in case we deal with a symlink, make sure we don't replace it
 		# with a real file (sed -i does that)
 		if [[ -L ${fn} ]] ; then
 			rf=$(readlink ${fn})
 			[[ ${rf} != /* ]] && rf=${fn%/*}/${rf}
+			# ignore symlinks pointing to outside prefix
+			# as seen in sys-devel/native-cctools
+			[[ ${rf} != ${EPREFIX}/* && $(canonicalize "${rf}") != ${eprefix}/* ]] && continue
 		fi
-		# line[0] can be an absolutised path, bug #342929
-		local eprefix=$(canonicalize ${EPREFIX})
 		# does the shebang start with ${EPREFIX}, and does it exist?
 		if [[ ${line[0]} == ${EPREFIX}/* || ${line[0]} == ${eprefix}/* ]] ; then
 			if [[ ! -e ${ROOT%/}${line[0]} && ! -e ${D%/}${line[0]} ]] ; then



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-08-20 18:35 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-08-20 18:35 UTC (permalink / raw
  To: gentoo-commits

commit:     0b4156a55f460d501145936fe7d1dec022f5a5f9
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sat Aug 20 18:32:09 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sat Aug 20 18:32:09 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=0b4156a5

fix-shebangs: fix regression for symlinked files

The code to check whether symlinked files point outside the prefix was
incorrect.  It didn't include the install image location, hence it
always concluded a symlinked script was pointing to outside the prefix,
leading to bugs like #378515.

---
 bin/misc-functions.sh |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index eb2235d..750f500 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -839,7 +839,7 @@ install_qa_check_prefix() {
 			[[ ${rf} != /* ]] && rf=${fn%/*}/${rf}
 			# ignore symlinks pointing to outside prefix
 			# as seen in sys-devel/native-cctools
-			[[ ${rf} != ${EPREFIX}/* && $(canonicalize "${rf}") != ${eprefix}/* ]] && continue
+			[[ $(canonicalize "/${rf#${D}}") != ${eprefix}/* ]] && continue
 		fi
 		# does the shebang start with ${EPREFIX}, and does it exist?
 		if [[ ${line[0]} == ${EPREFIX}/* || ${line[0]} == ${eprefix}/* ]] ; then



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-09-13 18:45 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-09-13 18:45 UTC (permalink / raw
  To: gentoo-commits

commit:     9727a7d287d8c0e27bccaa6e04f7f70155e31b30
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Tue Sep 13 18:45:45 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Tue Sep 13 18:45:45 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=9727a7d2

bin/: bring back Prefix changes to new files

---
 bin/bashrc-functions.sh |    4 +-
 bin/phase-functions.sh  |   13 ++++++---
 bin/phase-helpers.sh    |   70 +++++++++++++++++++++++-----------------------
 bin/save-ebuild-env.sh  |    5 +++-
 4 files changed, 50 insertions(+), 42 deletions(-)

diff --git a/bin/bashrc-functions.sh b/bin/bashrc-functions.sh
index 4da5585..8018ae9 100644
--- a/bin/bashrc-functions.sh
+++ b/bin/bashrc-functions.sh
@@ -1,10 +1,10 @@
-#!/bin/bash
+#!@PREFIX_PORTAGE_BASH@
 # Copyright 1999-2011 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 portageq() {
 	PYTHONPATH=${PORTAGE_PYM_PATH}${PYTHONPATH:+:}${PYTHONPATH} \
-	"${PORTAGE_PYTHON:-/usr/bin/python}" "${PORTAGE_BIN_PATH}/portageq" "$@"
+	"${PORTAGE_PYTHON:-@PREFIX_PORTAGE_PYTHON@}" "${PORTAGE_BIN_PATH}/portageq" "$@"
 }
 
 register_die_hook() {

diff --git a/bin/phase-functions.sh b/bin/phase-functions.sh
index 164b309..77bba11 100644
--- a/bin/phase-functions.sh
+++ b/bin/phase-functions.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!@PREFIX_PORTAGE_BASH@
 # Copyright 1999-2011 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
@@ -27,7 +27,8 @@ PORTAGE_READONLY_VARS="D EBUILD EBUILD_PHASE \
 	PORTAGE_SAVED_READONLY_VARS PORTAGE_SIGPIPE_STATUS \
 	PORTAGE_TMPDIR PORTAGE_UPDATE_ENV PORTAGE_USERNAME \
 	PORTAGE_VERBOSE PORTAGE_WORKDIR_MODE PORTDIR PORTDIR_OVERLAY \
-	PROFILE_PATHS REPLACING_VERSIONS REPLACED_BY_VERSION T WORKDIR"
+	PROFILE_PATHS REPLACING_VERSIONS REPLACED_BY_VERSION T WORKDIR \
+	ED EROOT"
 
 PORTAGE_SAVED_READONLY_VARS="A CATEGORY P PF PN PR PV PVR"
 
@@ -98,7 +99,9 @@ filter_readonly_variables() {
 		0|1|2)
 			;;
 		*)
-			filtered_vars+=" ED EPREFIX EROOT"
+			# PREFIX LOCAL: always respect these
+			#filtered_vars+=" ED EPREFIX EROOT"
+			# PREFIX LOCAL
 			;;
 	esac
 
@@ -126,7 +129,7 @@ filter_readonly_variables() {
 		"
 	fi
 
-	"${PORTAGE_PYTHON:-/usr/bin/python}" "${PORTAGE_BIN_PATH}"/filter-bash-environment.py "${filtered_vars}" || die "filter-bash-environment.py failed"
+	"${PORTAGE_PYTHON:-@PREFIX_PORTAGE_PYTHON@}" "${PORTAGE_BIN_PATH}"/filter-bash-environment.py "${filtered_vars}" || die "filter-bash-environment.py failed"
 }
 
 # @FUNCTION: preprocess_ebuild_env
@@ -550,6 +553,7 @@ dyn_install() {
 	fi
 	echo "${USE}"       > USE
 	echo "${EAPI:-0}"   > EAPI
+	echo "${EPREFIX}"   > EPREFIX
 	set +f
 
 	# local variables can leak into the saved environment.
@@ -632,6 +636,7 @@ dyn_help() {
 		echo "production (stripped)"
 	fi
 	echo "  merge to    : ${ROOT}"
+	echo "  offset      : ${EPREFIX}"
 	echo
 	if [ -n "$USE" ]; then
 		echo "Additionally, support for the following optional features will be enabled:"

diff --git a/bin/phase-helpers.sh b/bin/phase-helpers.sh
index a033fa8..04cc291 100644
--- a/bin/phase-helpers.sh
+++ b/bin/phase-helpers.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!@PREFIX_PORTAGE_BASH@
 # Copyright 1999-2011 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
@@ -19,8 +19,8 @@ into() {
 		export DESTTREE=""
 	else
 		export DESTTREE=$1
-		if [ ! -d "${D}${DESTTREE}" ]; then
-			install -d "${D}${DESTTREE}"
+		if [ ! -d "${ED}${DESTTREE}" ]; then
+			install -d "${ED}${DESTTREE}"
 			local ret=$?
 			if [[ $ret -ne 0 ]] ; then
 				helpers_die "${FUNCNAME[0]} failed"
@@ -35,8 +35,8 @@ insinto() {
 		export INSDESTTREE=""
 	else
 		export INSDESTTREE=$1
-		if [ ! -d "${D}${INSDESTTREE}" ]; then
-			install -d "${D}${INSDESTTREE}"
+		if [ ! -d "${ED}${INSDESTTREE}" ]; then
+			install -d "${ED}${INSDESTTREE}"
 			local ret=$?
 			if [[ $ret -ne 0 ]] ; then
 				helpers_die "${FUNCNAME[0]} failed"
@@ -51,8 +51,8 @@ exeinto() {
 		export _E_EXEDESTTREE_=""
 	else
 		export _E_EXEDESTTREE_="$1"
-		if [ ! -d "${D}${_E_EXEDESTTREE_}" ]; then
-			install -d "${D}${_E_EXEDESTTREE_}"
+		if [ ! -d "${ED}${_E_EXEDESTTREE_}" ]; then
+			install -d "${ED}${_E_EXEDESTTREE_}"
 			local ret=$?
 			if [[ $ret -ne 0 ]] ; then
 				helpers_die "${FUNCNAME[0]} failed"
@@ -67,8 +67,8 @@ docinto() {
 		export _E_DOCDESTTREE_=""
 	else
 		export _E_DOCDESTTREE_="$1"
-		if [ ! -d "${D}usr/share/doc/${PF}/${_E_DOCDESTTREE_}" ]; then
-			install -d "${D}usr/share/doc/${PF}/${_E_DOCDESTTREE_}"
+		if [ ! -d "${ED}usr/share/doc/${PF}/${_E_DOCDESTTREE_}" ]; then
+			install -d "${ED}usr/share/doc/${PF}/${_E_DOCDESTTREE_}"
 			local ret=$?
 			if [[ $ret -ne 0 ]] ; then
 				helpers_die "${FUNCNAME[0]} failed"
@@ -135,7 +135,7 @@ keepdir() {
 	local x
 	if [ "$1" == "-R" ] || [ "$1" == "-r" ]; then
 		shift
-		find "$@" -type d -printf "${D}%p/.keep_${CATEGORY}_${PN}-${SLOT}\n" \
+		find "$@" -type d -printf "${ED}%p/.keep_${CATEGORY}_${PN}-${SLOT}\n" \
 			| tr "\n" "\0" | \
 			while read -r -d $'\0' ; do
 				>> "$REPLY" || \
@@ -143,7 +143,7 @@ keepdir() {
 			done
 	else
 		for x in "$@"; do
-			>> "${D}${x}/.keep_${CATEGORY}_${PN}-${SLOT}" || \
+			>> "${ED}${x}/.keep_${CATEGORY}_${PN}-${SLOT}" || \
 				die "Failed to create .keep in ${D}${x}"
 		done
 	fi
@@ -398,12 +398,12 @@ econf() {
 			sed -e "1s:^#![[:space:]]*/bin/sh:#!$CONFIG_SHELL:" -i "$ECONF_SOURCE/configure" || \
 				die "Substition of shebang in '$ECONF_SOURCE/configure' failed"
 		fi
-		if [ -e /usr/share/gnuconfig/ ]; then
+		if [ -e "${EPREFIX}"/usr/share/gnuconfig/ ]; then
 			find "${WORKDIR}" -type f '(' \
 			-name config.guess -o -name config.sub ')' -print0 | \
 			while read -r -d $'\0' x ; do
-				vecho " * econf: updating ${x/${WORKDIR}\/} with /usr/share/gnuconfig/${x##*/}"
-				cp -f /usr/share/gnuconfig/"${x##*/}" "${x}"
+				vecho " * econf: updating ${x/${WORKDIR}\/} with ${EPREFIX}/usr/share/gnuconfig/${x##*/}"
+				cp -f "${EPREFIX}"/usr/share/gnuconfig/"${x##*/}" "${x}"
 			done
 		fi
 
@@ -423,7 +423,7 @@ econf() {
 		if [[ -n ${CONF_LIBDIR} ]] && ! _hasgq --libdir=\* "$@" ; then
 			export CONF_PREFIX=$(_hasg --exec-prefix=\* "$@")
 			[[ -z ${CONF_PREFIX} ]] && CONF_PREFIX=$(_hasg --prefix=\* "$@")
-			: ${CONF_PREFIX:=/usr}
+			: ${CONF_PREFIX:=${EPREFIX}/usr}
 			CONF_PREFIX=${CONF_PREFIX#*=}
 			[[ ${CONF_PREFIX} != /* ]] && CONF_PREFIX="/${CONF_PREFIX}"
 			[[ ${CONF_LIBDIR} != /* ]] && CONF_LIBDIR="/${CONF_LIBDIR}"
@@ -431,15 +431,15 @@ econf() {
 		fi
 
 		set -- \
-			--prefix=/usr \
+			--prefix="${EPREFIX}"/usr \
 			${CBUILD:+--build=${CBUILD}} \
 			--host=${CHOST} \
 			${CTARGET:+--target=${CTARGET}} \
-			--mandir=/usr/share/man \
-			--infodir=/usr/share/info \
-			--datadir=/usr/share \
-			--sysconfdir=/etc \
-			--localstatedir=/var/lib \
+			--mandir="${EPREFIX}"/usr/share/man \
+			--infodir="${EPREFIX}"/usr/share/info \
+			--datadir="${EPREFIX}"/usr/share \
+			--sysconfdir="${EPREFIX}"/etc \
+			--localstatedir="${EPREFIX}"/var/lib \
 			"$@" \
 			${EXTRA_ECONF}
 		vecho "${ECONF_SOURCE}/configure" "$@"
@@ -477,22 +477,22 @@ einstall() {
 
 	if [ -f ./[mM]akefile -o -f ./GNUmakefile ] ; then
 		if [ "${PORTAGE_DEBUG}" == "1" ]; then
-			${MAKE:-make} -n prefix="${D}usr" \
-				datadir="${D}usr/share" \
-				infodir="${D}usr/share/info" \
-				localstatedir="${D}var/lib" \
-				mandir="${D}usr/share/man" \
-				sysconfdir="${D}etc" \
+			${MAKE:-make} -n prefix="${ED}usr" \
+				datadir="${ED}usr/share" \
+				infodir="${ED}usr/share/info" \
+				localstatedir="${ED}var/lib" \
+				mandir="${ED}usr/share/man" \
+				sysconfdir="${ED}etc" \
 				${LOCAL_EXTRA_EINSTALL} \
 				${MAKEOPTS} ${EXTRA_EMAKE} -j1 \
 				"$@" install
 		fi
-		${MAKE:-make} prefix="${D}usr" \
-			datadir="${D}usr/share" \
-			infodir="${D}usr/share/info" \
-			localstatedir="${D}var/lib" \
-			mandir="${D}usr/share/man" \
-			sysconfdir="${D}etc" \
+		${MAKE:-make} prefix="${ED}usr" \
+			datadir="${ED}usr/share" \
+			infodir="${ED}usr/share/info" \
+			localstatedir="${ED}var/lib" \
+			mandir="${ED}usr/share/man" \
+			sysconfdir="${ED}etc" \
 			${LOCAL_EXTRA_EINSTALL} \
 			${MAKEOPTS} ${EXTRA_EMAKE} -j1 \
 			"$@" install || die "einstall failed"
@@ -589,7 +589,7 @@ has_version() {
 		"$PORTAGE_BIN_PATH"/ebuild-ipc has_version "$ROOT" "$1"
 	else
 		PYTHONPATH=${PORTAGE_PYM_PATH}${PYTHONPATH:+:}${PYTHONPATH} \
-		"${PORTAGE_PYTHON:-/usr/bin/python}" "${PORTAGE_BIN_PATH}/portageq" has_version "${ROOT}" "$1"
+		"${PORTAGE_PYTHON:-@PORTAGE_PREFIX_PYTHON@}" "${PORTAGE_BIN_PATH}/portageq" has_version "${ROOT}" "$1"
 	fi
 	local retval=$?
 	case "${retval}" in
@@ -610,7 +610,7 @@ best_version() {
 		"$PORTAGE_BIN_PATH"/ebuild-ipc best_version "$ROOT" "$1"
 	else
 		PYTHONPATH=${PORTAGE_PYM_PATH}${PYTHONPATH:+:}${PYTHONPATH} \
-		"${PORTAGE_PYTHON:-/usr/bin/python}" "${PORTAGE_BIN_PATH}/portageq" best_version "${ROOT}" "$1"
+		"${PORTAGE_PYTHON:-@PORTAGE_PREFIX_PYTHON@}" "${PORTAGE_BIN_PATH}/portageq" best_version "${ROOT}" "$1"
 	fi
 	local retval=$?
 	case "${retval}" in

diff --git a/bin/save-ebuild-env.sh b/bin/save-ebuild-env.sh
index a84a125..935adc4 100644
--- a/bin/save-ebuild-env.sh
+++ b/bin/save-ebuild-env.sh
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!@PORTAGE_PREFIX_BASH@
 # Copyright 1999-2011 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
@@ -88,6 +88,9 @@ save_ebuild_env() {
 	# user config variables
 	unset DOC_SYMLINKS_DIR INSTALL_MASK PKG_INSTALL_MASK
 
+	# Prefix additions
+	unset BPREFIX DEFAULT_PATH EPREFIX EXTRA_PATH PORTAGE_GROUP PORTAGE_USER
+
 	declare -p
 	declare -fp
 	if [[ ${BASH_VERSINFO[0]} == 3 ]]; then



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-09-23 18:23 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-09-23 18:23 UTC (permalink / raw
  To: gentoo-commits

commit:     9fae17af23e56d8c2ce357672c2095670b697b3c
Author:     MATSUI Tetsushi <VED03370 <AT> nifty <DOT> ne <DOT> jp>
AuthorDate: Fri Sep 23 18:22:20 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Fri Sep 23 18:22:20 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=9fae17af

dispatch-conf: fix for Prefix, bug #384217

---
 bin/dispatch-conf |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/dispatch-conf b/bin/dispatch-conf
index fe85c54..d96c94a 100755
--- a/bin/dispatch-conf
+++ b/bin/dispatch-conf
@@ -78,7 +78,7 @@ class dispatch:
         confs = []
         count = 0
 
-        config_root = '/'
+        config_root = EPREFIX
         self.options = portage.dispatch_conf.read_config(MANDATORY_OPTS)
 
         if "log-file" in self.options:



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-09-23 18:33 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-09-23 18:33 UTC (permalink / raw
  To: gentoo-commits

commit:     4f65e5be9db17ad0e94993740270ab9a0bb1d9e1
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Fri Sep 23 18:32:13 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Fri Sep 23 18:32:13 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=4f65e5be

misc-functions.sh: PORTAGE_CONFIGROOT contains EPREFIX by default

---
 bin/misc-functions.sh |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index cf72dee..148d038 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -1558,7 +1558,7 @@ preinst_suid_scan() {
 	# total suid control.
 	if has suidctl $FEATURES; then
 		local i sfconf x
-		sfconf=${PORTAGE_CONFIGROOT}${EPREFIX#/}/etc/portage/suidctl.conf
+		sfconf=${PORTAGE_CONFIGROOT}etc/portage/suidctl.conf
 		# sandbox prevents us from writing directly
 		# to files outside of the sandbox, but this
 		# can easly be bypassed using the addwrite() function



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-12-03 15:22 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-12-03 15:22 UTC (permalink / raw
  To: gentoo-commits

commit:     d6b379cff421282d6a0dac5f4ea65be40df4175a
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sat Dec  3 15:19:56 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sat Dec  3 15:19:56 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=d6b379cf

misc-functions.sh: don't set local ED/EPREFIX some more

In Prefix EPREFIX, ED are always set, so don't try to redefine them with
wrong values (or local).  In fact, it fails because ED and EPREFIX are
defined as read-only.

---
 bin/misc-functions.sh |   24 ++++++++++++++++++------
 1 files changed, 18 insertions(+), 6 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 58f5bc8..20d52a7 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -70,7 +70,9 @@ canonicalize() {
 prepcompress() {
 	local -a include exclude incl_d incl_f
 	local f g i real_f real_d
-	case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# PREFIX LOCAL: always support ED
+	#case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# END PREFIX LOCAL
 
 	# Canonicalize path names and check for their existence.
 	real_d=$(canonicalize "${ED}")
@@ -1514,7 +1516,9 @@ preinst_mask() {
 		 return 1
 	fi
 
-	case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# PREFIX LOCAL: always support ED
+	#case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# END PREFIX LOCAL
 
 	# Make sure $PWD is not ${D} so that we don't leave gmon.out files
 	# in there in case any tools were built with -pg in CFLAGS.
@@ -1542,7 +1546,9 @@ preinst_sfperms() {
 		 return 1
 	fi
 
-	case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# PREFIX LOCAL: always support ED
+	#case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# END PREFIX LOCAL
 
 	# Smart FileSystem Permissions
 	if has sfperms $FEATURES; then
@@ -1580,7 +1586,9 @@ preinst_suid_scan() {
 		 return 1
 	fi
 
-	case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# PREFIX LOCAL: always support ED
+	#case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# END PREFIX LOCAL
 
 	# total suid control.
 	if has suidctl $FEATURES; then
@@ -1645,7 +1653,9 @@ preinst_selinux_labels() {
 
 dyn_package() {
 
-	case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# PREFIX LOCAL: always support ED
+	#case "$EAPI" in 0|1|2) local ED=${D} ;; esac
+	# END PREFIX LOCAL
 
 	# Make sure $PWD is not ${D} so that we don't leave gmon.out files
 	# in there in case any tools were built with -pg in CFLAGS.
@@ -1725,7 +1735,9 @@ __END1__
 
 dyn_rpm() {
 
-	case "$EAPI" in 0|1|2) local EPREFIX= ;; esac
+	# PREFIX LOCAL: always support ED
+	#case "$EAPI" in 0|1|2) local EPREFIX= ;; esac
+	# END PREFIX LOCAL
 
 	cd "${T}" || die "cd failed"
 	local machine_name=$(uname -m)



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-12-03 16:49 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-12-03 16:49 UTC (permalink / raw
  To: gentoo-commits

commit:     680c4144051d0b72a0066de5dbec2f20e8d0d71b
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sat Dec  3 16:47:25 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sat Dec  3 16:47:25 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=680c4144

portageq: fix root/eroot handling for Prefix

__PORTAGE_TEST_EPREFIX will almost always be empty, hence the code
believes that no offset prefix is in use.  In Prefix, this is always on
the contrary, so when not set, use the hardwired EPREFIX from
portage.const.  This avoids double prefixes seen for the portageq
functions, and hence funcs like has_version always return false.

---
 bin/portageq |    4 ++++
 1 files changed, 4 insertions(+), 0 deletions(-)

diff --git a/bin/portageq b/bin/portageq
index fe980a2..27a77a8 100755
--- a/bin/portageq
+++ b/bin/portageq
@@ -843,6 +843,10 @@ def main():
 			sys.stderr.flush()
 			sys.exit(os.EX_USAGE)
 		eprefix = os.environ.get("__PORTAGE_TEST_EPREFIX")
+		# PREFIX LOCAL: make sure we fall back to our hardwired EPREFIX
+		if not eprefix:
+			eprefix = portage.const.EPREFIX
+		# END PREFIX LOCAL
 		eroot = portage.util.normalize_path(sys.argv[2])
 		if eprefix:
 			root = eroot[:1-len(eprefix)]



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-12-09 20:36 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-12-09 20:36 UTC (permalink / raw
  To: gentoo-commits

commit:     0428b8e125d86a080d385ff7db5a95e4813fc7d2
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Fri Dec  9 20:36:14 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Fri Dec  9 20:36:14 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=0428b8e1

phase-functions: remove conflict markers

---
 bin/phase-functions.sh |    4 ----
 1 files changed, 0 insertions(+), 4 deletions(-)

diff --git a/bin/phase-functions.sh b/bin/phase-functions.sh
index 75f1664..40decb7 100644
--- a/bin/phase-functions.sh
+++ b/bin/phase-functions.sh
@@ -559,9 +559,6 @@ dyn_install() {
 	fi
 	echo "${USE}"       > USE
 	echo "${EAPI:-0}"   > EAPI
-<<<<<<< HEAD
-	echo "${EPREFIX}"   > EPREFIX
-=======
 
 	# Save EPREFIX, since it makes it easy to use chpathtool to
 	# adjust the content of a binary package so that it will
@@ -576,7 +573,6 @@ dyn_install() {
 			;;
 	esac
 
->>>>>>> overlays-gentoo-org/master
 	set +f
 
 	# local variables can leak into the saved environment.



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2011-12-10 13:14 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2011-12-10 13:14 UTC (permalink / raw
  To: gentoo-commits

commit:     80468771dc34cc60ebc9441a3b9767db132d18f8
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sat Dec 10 13:14:09 2011 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sat Dec 10 13:14:09 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=80468771

save_ebuild_env: EPREFIX has become a readonly variable now

---
 bin/save-ebuild-env.sh |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/save-ebuild-env.sh b/bin/save-ebuild-env.sh
index f765600..b3f7f7b 100644
--- a/bin/save-ebuild-env.sh
+++ b/bin/save-ebuild-env.sh
@@ -92,7 +92,7 @@ save_ebuild_env() {
 	unset DOC_SYMLINKS_DIR INSTALL_MASK PKG_INSTALL_MASK
 
 	# Prefix additions
-	unset BPREFIX DEFAULT_PATH EPREFIX EXTRA_PATH PORTAGE_GROUP PORTAGE_USER
+	unset BPREFIX DEFAULT_PATH EXTRA_PATH PORTAGE_GROUP PORTAGE_USER
 
 	declare -p
 	declare -fp



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-04-03 18:09 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-04-03 18:09 UTC (permalink / raw
  To: gentoo-commits

commit:     85b951b73f528a3c97156a7644d7eac16ed835c0
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Tue Apr  3 18:09:18 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Tue Apr  3 18:09:18 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=85b951b7

Makefile: fix install location of emerge-webrsync, bug #410669

---
 bin/Makefile.in |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/Makefile.in b/bin/Makefile.in
index ab2f3b7..bd751c9 100644
--- a/bin/Makefile.in
+++ b/bin/Makefile.in
@@ -20,6 +20,7 @@ usr_binprogs = \
 	ebuild \
 	egencache \
 	emerge \
+	emerge-webrsync \
 	portageq \
 	quickpkg \
 	repoman
@@ -28,7 +29,6 @@ usr_sbinprogs = \
 	archive-conf \
 	dispatch-conf \
 	emaint \
-	emerge-webrsync \
 	env-update \
 	etc-update \
 	fixpackages \



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-07-08 17:25 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-07-08 17:25 UTC (permalink / raw
  To: gentoo-commits

commit:     7b62265a8cdadb923d4138d59f252d69bd8138b6
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Jul  8 17:25:01 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Jul  8 17:25:01 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=7b62265a

build-sys: undo too aggressive glob change

in bin/ we DO need the local directory to be processed as well

---
 bin/Makefile.in |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/Makefile.in b/bin/Makefile.in
index 9a5b59a..e9bf141 100644
--- a/bin/Makefile.in
+++ b/bin/Makefile.in
@@ -39,7 +39,7 @@ all:
 
 install:
 	$(INSTALL) -d -m 755 -o "$(portageuser)" -g "$(portagegroup)" $(DESTDIR)$(PORTAGE_BIN)
-	( cd "$(srcdir)" && find * -type d ) | while read f ; do \
+	( cd "$(srcdir)" && find . -type d ) | while read f ; do \
 		files=( ) ; \
 		for t in "$(srcdir)/$${f}"/* ; do \
 			[[ -d $${t} ]] && continue ; \



^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-08-12  7:44 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-08-12  7:44 UTC (permalink / raw
  To: gentoo-commits

commit:     909779359b10c327ccf0e79a3ee6703330901e74
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Aug 12 07:43:34 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Aug 12 07:43:34 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=90977935

install_qa_check_prefix: drop removal of etc/{init,conf}.d files

This allows to use OpenRC on Prefix systems.

Signed-off-by: XU Benda <heroxbd <AT> gmail.com>

---
 bin/misc-functions.sh |   10 ----------
 1 files changed, 0 insertions(+), 10 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 496c2d7..d46ab06 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -904,16 +904,6 @@ install_qa_check_prefix() {
 	# all further checks rely on ${ED} existing
 	[[ -d ${ED} ]] || return
 
-	# this does not really belong here, but it's closely tied to
-	# the code below; many runscripts generate positives here, and we
-	# know they don't work (bug #196294) so as long as that one
-	# remains an issue, simply remove them as they won't work
-	# anyway, avoid etc/init.d/functions.sh from being thrown away
-	if [[ ( -d "${ED}"/etc/conf.d || -d "${ED}"/etc/init.d ) && ! -f "${ED}"/etc/init.d/functions.sh ]] ; then
-		ewarn "removed /etc/init.d and /etc/conf.d directories until bug #196294 has been resolved"
-		rm -Rf "${ED}"/etc/{conf,init}.d
-	fi
-
 	# check shebangs, bug #282539
 	rm -f "${T}"/non-prefix-shebangs-errs
 	local WHITELIST=" /usr/bin/env "


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-09-12 18:26 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-09-12 18:26 UTC (permalink / raw
  To: gentoo-commits

commit:     eb39f4906a33c53ba4af8070d4c449d40eb2026a
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Wed Sep 12 18:24:24 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Wed Sep 12 18:24:24 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=eb39f490

install_qa_check_prefix: auto fix shebang of init-scripts

Always consider scripts in ${EPREFIX}/etc/init.d as must-fixable.

---
 bin/misc-functions.sh |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/bin/ebuild.sh b/bin/ebuild.sh
index d4dde05..9df77ee 100755
--- a/bin/ebuild.sh
+++ b/bin/ebuild.sh
@@ -176,7 +176,7 @@ debug-print() {
 		# default target
 		printf '%s\n' "${@}" >> "${T}/eclass-debug.log"
 		# let the portage user own/write to this file
-		chgrp portage "${T}/eclass-debug.log" &>/dev/null
+		chgrp ${PORTAGE_GROUP} "${T}/eclass-debug.log" &>/dev/null
 		chmod g+w "${T}/eclass-debug.log" &>/dev/null
 	fi
 }


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-10-22 17:57 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-10-22 17:57 UTC (permalink / raw
  To: gentoo-commits

commit:     95d3c9ff2b0f6690af53830dfbfc8ce60f9ee00f
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Oct 22 17:57:23 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Oct 22 17:57:23 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=95d3c9ff

PORTAGE_GRPNAME: don't fall back to hardcoded 'portage'

---
 bin/ebuild.sh          |    2 +-
 bin/phase-functions.sh |    2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/bin/ebuild.sh b/bin/ebuild.sh
index c3fadd4..b710e5e 100755
--- a/bin/ebuild.sh
+++ b/bin/ebuild.sh
@@ -180,7 +180,7 @@ debug-print() {
 		# default target
 		printf '%s\n' "${@}" >> "${T}/eclass-debug.log"
 		# let the portage user own/write to this file
-		chgrp "${PORTAGE_GRPNAME:-portage}" "${T}/eclass-debug.log"
+		chgrp "${PORTAGE_GRPNAME:-${PORTAGE_GROUP}}" "${T}/eclass-debug.log"
 		chmod g+w "${T}/eclass-debug.log"
 	fi
 }

diff --git a/bin/phase-functions.sh b/bin/phase-functions.sh
index b6d0737..fa293ee 100644
--- a/bin/phase-functions.sh
+++ b/bin/phase-functions.sh
@@ -972,7 +972,7 @@ __ebuild_main() {
 		__save_ebuild_env | __filter_readonly_variables \
 			--filter-features > "$T/environment"
 		assert "__save_ebuild_env failed"
-		chgrp "${PORTAGE_GRPNAME:-portage}" "$T/environment"
+		chgrp "${PORTAGE_GRPNAME:-${PORTAGE_GROUP}}" "$T/environment"
 		chmod g+w "$T/environment"
 	fi
 	[[ -n $PORTAGE_EBUILD_EXIT_FILE ]] && > "$PORTAGE_EBUILD_EXIT_FILE"


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-12-02 12:58 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-12-02 12:58 UTC (permalink / raw
  To: gentoo-commits

commit:     89c1b7cf341eb96b3fb65e9232523710da87455c
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Dec  2 12:55:21 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Dec  2 12:55:21 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=89c1b7cf

install_qa_check_macho: drop automagic fixing of install_names

Remove the fraction of the code that got moved to gen_usr_ldscript here:
http://overlays.gentoo.org/proj/alt/changeset/61477

This makes Portage's behaviour clearer, doing just checks, no fixing.
The latter went wrong for libraries that on an upgrade got moved, which
gen_usr_ldscript now should handle correctly, because it has more
context.

---
 bin/misc-functions.sh |   30 +++++-------------------------
 1 files changed, 5 insertions(+), 25 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index d64a61f..c30c7e0 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -1072,7 +1072,6 @@ install_qa_check_macho() {
 		fi
 
 		# this is ugly, paths with spaces won't work
-		reevaluate=0
 		for lib in ${needed//,/ } ; do
 			if [[ ${lib} == ${D}* ]] ; then
 				eqawarn "QA Notice: install_name references \${D}: ${lib} in ${obj}"
@@ -1081,32 +1080,13 @@ install_qa_check_macho() {
 				eqawarn "QA Notice: install_name references \${S}: ${lib} in ${obj}"
 				touch "${T}"/.install_name_check_failed
 			elif [[ ! -e ${lib} && ! -e ${D}${lib} && ${lib} != "@executable_path/"* && ${lib} != "@loader_path/"* ]] ; then
-				# try to "repair" this if possible, happens because of
-				# gen_usr_ldscript tactics
-				s=${lib%usr/*}${lib##*/usr/}
-				if [[ -e ${D}${s} ]] ; then
-					ewarn "correcting install_name from ${lib} to ${s} in ${obj}"
-					install_name_tool -change \
-						"${lib}" "${s}" "${D}${obj}"
-					reevaluate=1
-				else
-					eqawarn "QA Notice: invalid reference to ${lib} in ${obj}"
-					# remember we are in an implicit subshell, that's
-					# why we touch a file here ... ideally we should be
-					# able to die correctly/nicely here
-					touch "${T}"/.install_name_check_failed
-				fi
+				eqawarn "QA Notice: invalid reference to ${lib} in ${obj}"
+				# remember we are in an implicit subshell, that's
+				# why we touch a file here ... ideally we should be
+				# able to die correctly/nicely here
+				touch "${T}"/.install_name_check_failed
 			fi
 		done
-		if [[ ${reevaluate} == 1 ]]; then
-			# install_name(s) have been changed, refresh data so we
-			# store the correct meta data
-			l=$(scanmacho -qyF '%a;%p;%S;%n' ${D}${obj})
-			arch=${l%%;*}; l=${l#*;}
-			obj="/${l%%;*}"; l=${l#*;}
-			install_name=${l%%;*}; l=${l#*;}
-			needed=${l%%;*}; l=${l#*;}
-		fi
 
 		# backwards compatability
 		echo "${obj} ${needed}" >> "${PORTAGE_BUILDDIR}"/build-info/NEEDED


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-12-26 15:06 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-12-26 15:06 UTC (permalink / raw
  To: gentoo-commits

commit:     b60228c469479ec8c8d9f0de33395de68d33a46a
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Wed Dec 26 15:05:36 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Wed Dec 26 15:05:36 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=b60228c4

install_symlink_html_docs: remove superfluous EPREFIX

dosym already handles EPREFIX for us transparently, so don't add another
one.  Thanks Cyprien Nicolas in bug #442348.

---
 bin/misc-functions.sh |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 3684d7c..c997635 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -30,7 +30,7 @@ install_symlink_html_docs() {
 		local mydocdir docdir
 		for docdir in "${HTMLDOC_DIR:-does/not/exist}" "${PF}/html" "${PF}/HTML" "${P}/html" "${P}/HTML" ; do
 			if [ -d "usr/share/doc/${docdir}" ] ; then
-				mydocdir="${EPREFIX}/usr/share/doc/${docdir}"
+				mydocdir="/usr/share/doc/${docdir}"
 			fi
 		done
 		if [ -n "${mydocdir}" ] ; then


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-01-10 21:13 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-01-10 21:13 UTC (permalink / raw
  To: gentoo-commits

commit:     91a099d2e8455fe26766843e67affc10d90d2efa
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Thu Jan 10 21:13:27 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Thu Jan 10 21:13:27 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=91a099d2

build-sys: install and fix shebang of emirrordist

---
 bin/Makefile.in |    1 +
 bin/emirrordist |    2 +-
 2 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/bin/Makefile.in b/bin/Makefile.in
index e9bf141..8b4aac4 100644
--- a/bin/Makefile.in
+++ b/bin/Makefile.in
@@ -21,6 +21,7 @@ usr_binprogs = \
 	egencache \
 	emerge \
 	emerge-webrsync \
+	emirrordist \
 	portageq \
 	quickpkg \
 	repoman

diff --git a/bin/emirrordist b/bin/emirrordist
index 8d93de9..34f352b 100755
--- a/bin/emirrordist
+++ b/bin/emirrordist
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!@PREFIX_PORTAGE_PYTHON@
 # Copyright 2013 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-03-24  8:34 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-03-24  8:34 UTC (permalink / raw
  To: gentoo-commits

commit:     7c6fa447d67dd8d047901d2a42dffb91b6715832
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Mar 24 08:33:39 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Mar 24 08:33:39 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=7c6fa447

__save_ebuild_env: avoid calling compgen when it doesn't exist

---
 bin/save-ebuild-env.sh |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/bin/save-ebuild-env.sh b/bin/save-ebuild-env.sh
index 2a244b5..f7c7321 100644
--- a/bin/save-ebuild-env.sh
+++ b/bin/save-ebuild-env.sh
@@ -85,7 +85,8 @@ __save_ebuild_env() {
 	___eapi_has_package_manager_build_user && unset -f package_manager_build_user
 	___eapi_has_package_manager_build_group && unset -f package_manager_build_group
 
-	unset -f $(compgen -A function ___eapi_)
+	# PREFIX: compgen is not compiled in during bootstrap
+	type compgen > /dev/null && unset -f $(compgen -A function ___eapi_)
 
 	# portage config variables and variables set directly by portage
 	unset ACCEPT_LICENSE BAD BRACKET BUILD_PREFIX COLS \


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-03-24  8:45 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-03-24  8:45 UTC (permalink / raw
  To: gentoo-commits

commit:     c2d97fb949c82a4cee2e4f49d3a99f682643e7a9
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Mar 24 08:45:44 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Mar 24 08:45:44 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=c2d97fb9

__save_ebuild_env: silence errors in particular

---
 bin/save-ebuild-env.sh |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/save-ebuild-env.sh b/bin/save-ebuild-env.sh
index f7c7321..c6c1ff3 100644
--- a/bin/save-ebuild-env.sh
+++ b/bin/save-ebuild-env.sh
@@ -86,7 +86,7 @@ __save_ebuild_env() {
 	___eapi_has_package_manager_build_group && unset -f package_manager_build_group
 
 	# PREFIX: compgen is not compiled in during bootstrap
-	type compgen > /dev/null && unset -f $(compgen -A function ___eapi_)
+	type compgen >& /dev/null && unset -f $(compgen -A function ___eapi_)
 
 	# portage config variables and variables set directly by portage
 	unset ACCEPT_LICENSE BAD BRACKET BUILD_PREFIX COLS \


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-03-31 10:03 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-03-31 10:03 UTC (permalink / raw
  To: gentoo-commits

commit:     0818dd274d543736c77ba6508586fe56d2aa7acc
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Mar 31 10:03:19 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Mar 31 10:03:19 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=0818dd27

isolated-functions.sh: fix path for Prefix, bug #460382

---
 bin/isolated-functions.sh |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/bin/isolated-functions.sh b/bin/isolated-functions.sh
index c71953c..1d399b6 100644
--- a/bin/isolated-functions.sh
+++ b/bin/isolated-functions.sh
@@ -2,7 +2,7 @@
 # Copyright 1999-2012 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
-source "${PORTAGE_BIN_PATH:-/usr/lib/portage/bin}/eapi.sh"
+source "${PORTAGE_BIN_PATH:-@PORTAGE_BASE@/bin}/eapi.sh"
 
 # We need this next line for "die" and "assert". It expands
 # It _must_ preceed all the calls to die and assert.


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-08-16 12:50 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-08-16 12:50 UTC (permalink / raw
  To: gentoo-commits

commit:     3dcbf0a786b9bb8b2349fcbda95f125470fdac47
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Fri Aug 16 12:50:11 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Fri Aug 16 12:50:11 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=3dcbf0a7

emerge-webrsync: add missing quote

---
 bin/emerge-webrsync | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/bin/emerge-webrsync b/bin/emerge-webrsync
index df855de..4d86c35 100755
--- a/bin/emerge-webrsync
+++ b/bin/emerge-webrsync
@@ -46,7 +46,7 @@ eval "$("${portageq}" envvar -v DISTDIR EPREFIX FEATURES \
 	PORTAGE_NICENESS PORTAGE_REPOSITORIES PORTAGE_RSYNC_EXTRA_OPTS \
 	PORTAGE_RSYNC_OPTS PORTAGE_TMPDIR \
 	USERLAND http_proxy ftp_proxy \
-	PORTAGE_USER PORTAGE_GROUP)
+	PORTAGE_USER PORTAGE_GROUP)"
 export http_proxy ftp_proxy
 
 # PREFIX LOCAL: use Prefix servers, just because we want this and infra


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-09-12  7:32 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-09-12  7:32 UTC (permalink / raw
  To: gentoo-commits

commit:     1018ee15a3d627792340a1c18de6c7c5eb4f607f
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Thu Sep 12 07:32:04 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Thu Sep 12 07:32:04 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=1018ee15

emerge-webrsync: remove double shebang

---
 bin/emerge-webrsync | 1 -
 1 file changed, 1 deletion(-)

diff --git a/bin/emerge-webrsync b/bin/emerge-webrsync
index 4d86c35..3269461 100755
--- a/bin/emerge-webrsync
+++ b/bin/emerge-webrsync
@@ -1,5 +1,4 @@
 #!@PORTAGE_BASH@
-#!/bin/bash
 # Copyright 1999-2013 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 # Author: Karl Trygve Kalleberg <karltk@gentoo.org>


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-09-18 18:34 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-09-18 18:34 UTC (permalink / raw
  To: gentoo-commits

commit:     1ad2a8835601aa6b77a2aedcbc9d08e8eca0f2b9
Author:     Ryan Hill <dirtyepic <AT> gentoo <DOT> org>
AuthorDate: Sun Sep 15 00:29:38 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Wed Sep 18 18:33:36 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=1ad2a883

Flag  -Waggressive-loop-optimizations warnings.
This will fix bug #484840.

---
 bin/misc-functions.sh | 1 +
 1 file changed, 1 insertion(+)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 011e8ba..129f7d3 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -755,6 +755,7 @@ install_qa_check_misc() {
 			": warning: returning reference to temporary"
 			": warning: function returns address of local variable"
 			": warning: .*\\[-Wsizeof-pointer-memaccess\\]"
+			": warning: .*\\[-Waggressive-loop-optimizations\\]"
 			# this may be valid code :/
 			#": warning: multi-character character constant"
 			# need to check these two ...


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-09-18 18:34 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-09-18 18:34 UTC (permalink / raw
  To: gentoo-commits

commit:     a419b09eaf39e5415e140aa2df45ed73b323f8ef
Author:     Arfrever Frehtes Taifersar Arahesis <Arfrever <AT> Apache <DOT> Org>
AuthorDate: Mon Sep 16 05:03:02 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Wed Sep 18 18:33:36 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=a419b09e

Bug #485056: Fix portageq with Python <2.6.5.

---
 bin/portageq | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/bin/portageq b/bin/portageq
index 2acbc84..6bbb9be 100755
--- a/bin/portageq
+++ b/bin/portageq
@@ -1197,7 +1197,7 @@ def add_pquery_arguments(parser):
 				kwargs["help"] = opt_info["help"]
 			except KeyError:
 				pass
-			arg_group.add_argument(*pargs, **kwargs)
+			arg_group.add_argument(*pargs, **portage._native_kwargs(kwargs))
 
 
 def usage(argv):


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2013-10-06 19:01 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2013-10-06 19:01 UTC (permalink / raw
  To: gentoo-commits

commit:     ed8fd7998da3ee76be4e0e4fb440c9308cad19f3
Author:     Alan Hourihane <alanh <AT> fairlite <DOT> co <DOT> uk>
AuthorDate: Sun Oct  6 18:59:21 2013 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Oct  6 18:59:21 2013 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=ed8fd799

helper-functions: fix multiprocessing not to assume bi-directional pipe

The usage of the read/write fifos at the end of multiprocessing.eclass
results in failure on some non-Linux OS's due to POSIX claiming the
behaviour is undefined and not guaranteed.

http://pubs.opengroup.org/onlinepubs/7908799/xsh/open.html

The above document explicitly says....

O_RDWR
    Open for reading and writing. The result is undefined if this flag
    is applied to a FIFO.

---
 bin/helper-functions.sh | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/bin/helper-functions.sh b/bin/helper-functions.sh
index ecd78c3..c574612 100644
--- a/bin/helper-functions.sh
+++ b/bin/helper-functions.sh
@@ -21,8 +21,9 @@ __multijob_init() {
 	# Setup a pipe for children to write their pids to when they finish.
 	mj_control_pipe=$(mktemp -t multijob.XXXXXX)
 	rm "${mj_control_pipe}"
-	mkfifo "${mj_control_pipe}"
-	__redirect_alloc_fd mj_control_fd "${mj_control_pipe}"
+	mkfifo -m 600 "${mj_control_pipe}"
+	__redirect_alloc_fd mj_read_fd "${mj_control_pipe}"
+	__redirect_alloc_fd mj_write_fd "${mj_control_pipe}"
 	rm -f "${mj_control_pipe}"
 
 	# See how many children we can fork based on the user's settings.
@@ -31,13 +32,13 @@ __multijob_init() {
 }
 
 __multijob_child_init() {
-	trap 'echo ${BASHPID} $? >&'${mj_control_fd} EXIT
+	trap 'echo ${BASHPID} $? >&'${mj_write_fd} EXIT
 	trap 'exit 1' INT TERM
 }
 
 __multijob_finish_one() {
 	local pid ret
-	read -r -u ${mj_control_fd} pid ret
+	read -r -u ${mj_read_fd} pid ret
 	: $(( --mj_num_jobs ))
 	return ${ret}
 }


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2014-09-30 16:04 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2014-09-30 16:04 UTC (permalink / raw
  To: gentoo-commits

commit:     ef2636dbec8a3abb59646859ef28b07e6c3dd832
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Tue Sep 30 16:03:55 2014 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Tue Sep 30 16:03:55 2014 +0000
URL:        http://sources.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=ef2636db

install_qa_check_macho: fix syntax

---
 bin/misc-functions.sh | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 1904c25..fb874ac 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -372,20 +372,20 @@ install_qa_check_macho() {
 			# remember we are in an implicit subshell, that's
 			# why we touch a file here ... ideally we should be
 			# able to die correctly/nicely here
-			[[ -z ${ignore} && touch "${T}"/.install_name_check_failed
+			[[ -z ${ignore} ]] && touch "${T}"/.install_name_check_failed
 		fi
 
 		# this is ugly, paths with spaces won't work
 		for lib in ${needed//,/ } ; do
 			if [[ ${lib} == ${D}* ]] ; then
 				eqawarn "QA Notice: install_name references \${D}: ${lib} in ${obj}"
-				[[ -z ${ignore} && touch "${T}"/.install_name_check_failed
+				[[ -z ${ignore} ]] && touch "${T}"/.install_name_check_failed
 			elif [[ ${lib} == ${S}* ]] ; then
 				eqawarn "QA Notice: install_name references \${S}: ${lib} in ${obj}"
-				[[ -z ${ignore} && touch "${T}"/.install_name_check_failed
+				[[ -z ${ignore} ]] && touch "${T}"/.install_name_check_failed
 			elif ! install_name_is_relative ${lib} && [[ ! -e ${lib} && ! -e ${D}${lib} ]] ; then
 				eqawarn "QA Notice: invalid reference to ${lib} in ${obj}"
-				[[ -z ${ignore} && touch "${T}"/.install_name_check_failed
+				[[ -z ${ignore} ]] && touch "${T}"/.install_name_check_failed
 			fi
 		done
 


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2014-10-02 18:47 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2014-10-02 18:47 UTC (permalink / raw
  To: gentoo-commits

commit:     a0d6d04ad4a5bd52b7ed3639bd71370fe986024d
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Thu Oct  2 18:47:21 2014 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Thu Oct  2 18:47:21 2014 +0000
URL:        http://sources.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=a0d6d04a

portageq: fix backtrace due to changed variable

---
 bin/portageq | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/bin/portageq b/bin/portageq
index 7b9e177..d383d42 100755
--- a/bin/portageq
+++ b/bin/portageq
@@ -24,11 +24,13 @@ import os
 import types
 
 # for an explanation on this logic, see pym/_emerge/__init__.py
+# this differs from master, we need to revisit this when we can install
+# using distutils, like master
 if os.environ.__contains__("PORTAGE_PYTHONPATH"):
-	pym_path = os.environ["PORTAGE_PYTHONPATH"]
+	pym_paths = [ os.environ["PORTAGE_PYTHONPATH"] ]
 else:
-	pym_path = os.path.join(os.path.dirname(
-		os.path.dirname(os.path.realpath(__file__))), "pym")
+	pym_paths = [ os.path.join(os.path.dirname(
+		os.path.dirname(os.path.realpath(__file__))), "pym") ]
 # Avoid sandbox violations after Python upgrade.
 if os.environ.get("SANDBOX_ON") == "1":
 	sandbox_write = os.environ.get("SANDBOX_WRITE", "").split(":")


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2014-10-24 19:14 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2014-10-24 19:14 UTC (permalink / raw
  To: gentoo-commits

commit:     ef6d8896e3a142f28de0344a07ab80fe424bea5e
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Fri Oct 24 19:13:59 2014 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Fri Oct 24 19:13:59 2014 +0000
URL:        http://sources.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=ef6d8896

misc-functions: fix usage of vecho, bug #519228

---
 bin/misc-functions.sh | 24 ++++++++++++------------
 1 file changed, 12 insertions(+), 12 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index fb874ac..5b8e872 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -291,7 +291,7 @@ install_qa_check_macho() {
 		done
 		if [[ -f ${T}/mach-o.check ]] ; then
 			f=$(< "${T}/mach-o.check")
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 			eqawarn "QA Notice: Found .so dynamic libraries on Darwin:"
 			eqawarn "    ${f//$'\n'/\n    }"
 		fi
@@ -307,7 +307,7 @@ install_qa_check_macho() {
 		done
 		if [[ -f "${T}/mach-o.check" ]] ; then
 			f=$(< "${T}/mach-o.check")
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 			eqawarn "QA Notice: Found wrongly named dynamic libraries on Darwin:"
 			eqawarn "    ${f// /\n    }"
 		fi
@@ -439,12 +439,12 @@ install_qa_check_pecoff() {
 			echo "${rpath}" | grep '$ORIGIN' > /dev/null 2>&1 && echo "${obj}"; done;
 		)
 		if [[ -n ${f}${x} ]] ; then
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 			eqawarn "QA Notice: The following files contain insecure RUNPATH's"
 			eqawarn " Please file a bug about this at http://bugs.gentoo.org/"
 			eqawarn " with the maintaining herd of the package."
 			eqawarn "${f}${f:+${x:+\n}}${x}"
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 			if [[ -n ${x} ]] || has stricter ${FEATURES} ; then
 				insecure_rpath=1
 			else
@@ -503,10 +503,10 @@ install_qa_check_pecoff() {
 				xargs -0 ${_pfx_scan} | while IFS=";" read arch obj soname rpath needed; \
 				do [[ -z "${soname}" ]] && echo "${obj}"; done)
 			if [[ -n ${f} ]] ; then
-				vecho -ne '\a\n'
+				__vecho -ne '\a\n'
 				eqawarn "QA Notice: The following shared libraries lack a SONAME"
 				eqawarn "${f}"
-				vecho -ne '\a\n'
+				__vecho -ne '\a\n'
 				sleep 1
 			fi
 
@@ -514,10 +514,10 @@ install_qa_check_pecoff() {
 				xargs -0 ${_pfx_scan} | while IFS=";" read arch obj soname rpath needed; \
 				do [[ -z "${needed}" ]] && echo "${obj}"; done)
 			if [[ -n ${f} ]] ; then
-				vecho -ne '\a\n'
+				__vecho -ne '\a\n'
 				eqawarn "QA Notice: The following shared libraries lack NEEDED entries"
 				eqawarn "${f}"
-				vecho -ne '\a\n'
+				__vecho -ne '\a\n'
 				sleep 1
 			fi
 		done
@@ -629,21 +629,21 @@ install_qa_check_xcoff() {
 		eval "exec ${neededfd}>&-" || die "cannot close handle to ${PORTAGE_BUILDDIR}/build-info/NEEDED.XCOFF.1"
 
 		if [[ -n ${undefined_symbols_list} ]]; then
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 			eqawarn "QA Notice: The following files contain undefined symbols."
 			eqawarn " Please file a bug about this at http://bugs.gentoo.org/"
 			eqawarn " with 'prefix' as the maintaining herd of the package."
 			eqawarn "${undefined_symbols_list}"
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 		fi
 
 		if [[ -n ${insecure_rpath_list} ]] ; then
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 			eqawarn "QA Notice: The following files contain insecure RUNPATH's"
 			eqawarn " Please file a bug about this at http://bugs.gentoo.org/"
 			eqawarn " with 'prefix' as the maintaining herd of the package."
 			eqawarn "${insecure_rpath_list}"
-			vecho -ne '\a\n'
+			__vecho -ne '\a\n'
 			if has stricter ${FEATURES} ; then
 				insecure_rpath=1
 			fi


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2017-03-23 15:25 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2017-03-23 15:25 UTC (permalink / raw
  To: gentoo-commits

commit:     f526e2997c95b807a053a54eb5ea823f2c7bf5fe
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Thu Mar 23 15:24:42 2017 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Thu Mar 23 15:24:42 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=f526e299

bashrc-functions: remove portageq wrapper

This wrapper should've been removed when 61c34d8 was merged.  A merge
conflict likely confused me.  Thanks haubi for noticing.

 bin/bashrc-functions.sh | 5 -----
 1 file changed, 5 deletions(-)

diff --git a/bin/bashrc-functions.sh b/bin/bashrc-functions.sh
index daa00d217..f01f5c5d0 100644
--- a/bin/bashrc-functions.sh
+++ b/bin/bashrc-functions.sh
@@ -2,11 +2,6 @@
 # Copyright 1999-2014 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
-portageq() {
-	PYTHONPATH=${PORTAGE_PYTHONPATH:-${PORTAGE_PYM_PATH}}\
-	"${PORTAGE_PYTHON:-@PREFIX_PORTAGE_PYTHON@}" "${PORTAGE_BIN_PATH}/portageq" "$@"
-}
-
 register_die_hook() {
 	local x
 	for x in $* ; do


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2017-03-24  7:43 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2017-03-24  7:43 UTC (permalink / raw
  To: gentoo-commits

commit:     608609bb8b38326bc74aa4b6cec27586c8e77d49
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Fri Mar 24 06:51:17 2017 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Fri Mar 24 06:51:17 2017 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=608609bb

bin: add executable bit on files that need it

 bin/misc-functions.sh  | 0
 bin/readpecoff         | 0
 bin/save-ebuild-env.sh | 0
 3 files changed, 0 insertions(+), 0 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
old mode 100644
new mode 100755

diff --git a/bin/readpecoff b/bin/readpecoff
old mode 100644
new mode 100755

diff --git a/bin/save-ebuild-env.sh b/bin/save-ebuild-env.sh
old mode 100644
new mode 100755


^ permalink raw reply	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2018-12-06 12:46 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2018-12-06 12:46 UTC (permalink / raw
  To: gentoo-commits

commit:     73c1fbe000df372ca1c6eed750ede06216b9b774
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Thu Dec  6 12:45:38 2018 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Thu Dec  6 12:45:38 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=73c1fbe0

bin/etc-update: ensure we ignore the host for Prefix

Bug: https://bugs.gentoo.org/669290
Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/etc-update | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/bin/etc-update b/bin/etc-update
index 4208b9f2b..d75388bba 100755
--- a/bin/etc-update
+++ b/bin/etc-update
@@ -32,7 +32,7 @@ get_config() {
 		"${PORTAGE_CONFIGROOT}"etc/etc-update.conf)
 }
 
-OS_RELEASE_ID=$(cat /etc/os-release 2>/dev/null | grep '^ID=' | cut -d'=' -f2 | sed -e 's/"//g')
+OS_RELEASE_ID=$(cat "@PORTAGE_EPREFIX@"/etc/os-release 2>/dev/null | grep '^ID=' | cut -d'=' -f2 | sed -e 's/"//g')
 
 case $OS_RELEASE_ID in
 	suse|opensuse|opensuse-leap|opensuse-tumbleweed) OS_FAMILY='rpm' ;;


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2018-12-23 19:55 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2018-12-23 19:55 UTC (permalink / raw
  To: gentoo-commits

commit:     6192f2c0efcbd3633321929a5d2863ec1a87610c
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Dec 23 19:54:27 2018 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Dec 23 19:54:27 2018 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=6192f2c0

bin/misc-functions.sh: restore canonicalize function

aa0a94198794f8ee8eedad26251b02f7b01dce17 removed this function without
really mentioning it.  In Prefix it's used for QA checks.

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/misc-functions.sh | 36 ++++++++++++++++++++++++++++++++++++
 1 file changed, 36 insertions(+)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 0590a2862..692becaf6 100755
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -47,6 +47,42 @@ install_symlink_html_docs() {
 	fi
 }
 
+# PREFIX LOCAL: we need this on some platforms
+# replacement for "readlink -f" or "realpath"
+READLINK_F_WORKS=""
+canonicalize() {
+	if [[ -z ${READLINK_F_WORKS} ]] ; then
+		if [[ $(readlink -f -- /../ 2>/dev/null) == "/" ]] ; then
+			READLINK_F_WORKS=true
+		else
+			READLINK_F_WORKS=false
+		fi
+	fi
+	if ${READLINK_F_WORKS} ; then
+		readlink -f -- "$@"
+		return
+	fi
+
+	local f=$1 b n=10 wd=$(pwd)
+	while (( n-- > 0 )); do
+		while [[ ${f: -1} = / && ${#f} -gt 1 ]]; do
+			f=${f%/}
+		done
+		b=${f##*/}
+		cd "${f%"${b}"}" 2>/dev/null || break
+		if [[ ! -L ${b} ]]; then
+			f=$(pwd -P)
+			echo "${f%/}/${b}"
+			cd "${wd}"
+			return 0
+		fi
+		f=$(readlink "${b}")
+	done
+	cd "${wd}"
+	return 1
+}
+# END PREFIX LOCAL
+
 install_qa_check() {
 	local d f i qa_var x paths qa_checks=() checks_run=()
 	if ! ___eapi_has_prefix_variables; then


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2019-06-03 19:00 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2019-06-03 19:00 UTC (permalink / raw
  To: gentoo-commits

commit:     2c3d2dc5c1637afc788142155234436f068f9016
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Jun  3 18:59:47 2019 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Jun  3 18:59:47 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=2c3d2dc5

bin/save-ebuild-env: fix shebang

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/save-ebuild-env.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/bin/save-ebuild-env.sh b/bin/save-ebuild-env.sh
index 1cfd79f23..7d7235f23 100755
--- a/bin/save-ebuild-env.sh
+++ b/bin/save-ebuild-env.sh
@@ -1,4 +1,4 @@
-#!@PORTAGE_PREFIX_BASH@
+#!@PORTAGE_BASH@
 # Copyright 1999-2018 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2019-06-03 19:21 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2019-06-03 19:21 UTC (permalink / raw
  To: gentoo-commits

commit:     c61168bfea27afcc8daf85976f67e8a84db3427b
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Jun  3 19:20:52 2019 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Jun  3 19:20:52 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=c61168bf

bin/chmod-lite: fix shebang and fallback python interpreter

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/chmod-lite | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/bin/chmod-lite b/bin/chmod-lite
index ffa8d4d23..8c62e2de7 100755
--- a/bin/chmod-lite
+++ b/bin/chmod-lite
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!@PORTAGE_BASH@
 # Copyright 2015 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
@@ -7,4 +7,4 @@ export __PORTAGE_HELPER_CWD=${PWD}
 # Use safe cwd, avoiding unsafe import for bug #469338.
 cd "${PORTAGE_PYM_PATH}" || exit 1
 PYTHONPATH=${PORTAGE_PYTHONPATH:-${PORTAGE_PYM_PATH}} \
-	exec "${PORTAGE_PYTHON:-/usr/bin/python}" "$PORTAGE_BIN_PATH/chmod-lite.py" "$@"
+	exec "${PORTAGE_PYTHON:-@PREFIX_PORTAGE_PYTHON@}" "$PORTAGE_BIN_PATH/chmod-lite.py" "$@"


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2019-07-01 13:11 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2019-07-01 13:11 UTC (permalink / raw
  To: gentoo-commits

commit:     b36d2dcd7d3a81e0b4632b7c4ff7147bac073dce
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Jul  1 13:09:39 2019 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Jul  1 13:09:39 2019 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=b36d2dcd

bin/chmod-lite: fix shebang

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/chmod-lite.py | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/bin/chmod-lite.py b/bin/chmod-lite.py
index 177be7eab..b9a4fc9a2 100755
--- a/bin/chmod-lite.py
+++ b/bin/chmod-lite.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python -b
+#!@PREFIX_PORTAGE_PYTHON@ -b
 # Copyright 2015 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2020-11-28 19:37 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2020-11-28 19:37 UTC (permalink / raw
  To: gentoo-commits

commit:     c3a69ee41aa0dd40342e05c7e275f82f31744ae1
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sat Nov 28 19:36:08 2020 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sat Nov 28 19:36:08 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=c3a69ee4

bin/misc-functions: resolve libraries from macOS SDK if configured

Bug: https://bugs.gentoo.org/757240
Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/misc-functions.sh | 24 +++++++++++++++++++++---
 1 file changed, 21 insertions(+), 3 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index d01a8edb1..8f62cb7f1 100755
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -360,9 +360,27 @@ install_qa_check_macho() {
 			elif [[ ${lib} == ${S}* ]] ; then
 				eqawarn "QA Notice: install_name references \${S}: ${lib} in ${obj}"
 				[[ -z ${ignore} ]] && touch "${T}"/.install_name_check_failed
-			elif ! install_name_is_relative ${lib} && [[ ! -e ${lib} && ! -e ${D}${lib} ]] ; then
-				eqawarn "QA Notice: invalid reference to ${lib} in ${obj}"
-				[[ -z ${ignore} ]] && touch "${T}"/.install_name_check_failed
+			elif ! install_name_is_relative ${lib} ; then
+				local isok=no
+				if [[ -e ${lib} || -e ${D}${lib} ]] ; then
+					isok=yes  # yay, we're ok
+				elif [[ -e "${EROOT}"/MacOSX.sdk ]] ; then
+					# trigger SDK mode, at least since Big Sur (11.0)
+					# there are no libraries in /usr/lib any more, but
+					# there are references too it (some library cache is
+					# in place), yet we can validate it sort of is sane
+					# by looking at the SDK metacaches, TAPI-files, .tbd
+					# text versions of libraries, so just look there
+					local tbd=${lib%.*}.tbd
+					if [[ -e ${EROOT}/MacOSX.sdk/${tbd} ]] ; then
+						isok=yes  # it's in the SDK, so ok
+					fi
+				fi
+				if [[ ${isok} == no ]] ; then
+					eqawarn "QA Notice: invalid reference to ${lib} in ${obj}"
+					[[ -z ${ignore} ]] && \
+						touch "${T}"/.install_name_check_failed
+				fi
 			fi
 		done
 


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2020-11-28 19:47 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2020-11-28 19:47 UTC (permalink / raw
  To: gentoo-commits

commit:     126b9931af386e5fe185f281595bf2da0156201c
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sat Nov 28 19:45:00 2020 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sat Nov 28 19:45:00 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=126b9931

bin/misc-functions: also resolve Frameworks from macOS SDK

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/misc-functions.sh | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 8f62cb7f1..c75c478ee 100755
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -372,8 +372,10 @@ install_qa_check_macho() {
 					# by looking at the SDK metacaches, TAPI-files, .tbd
 					# text versions of libraries, so just look there
 					local tbd=${lib%.*}.tbd
-					if [[ -e ${EROOT}/MacOSX.sdk/${tbd} ]] ; then
+					if [[ -e ${EROOT}/MacOSX.sdk/${lib%.*}.tbd ]] ; then
 						isok=yes  # it's in the SDK, so ok
+					elif [[ -e ${EROOT}/MacOSX.sdk/${lib}.tbd ]] ; then
+						isok=yes  # this happens in case of Framework refs
 					fi
 				fi
 				if [[ ${isok} == no ]] ; then


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2020-12-07 16:49 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2020-12-07 16:49 UTC (permalink / raw
  To: gentoo-commits

commit:     87cc6932b41bd9b612c53df10c68a2b93258b90d
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Dec  7 16:48:13 2020 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Dec  7 16:48:13 2020 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=87cc6932

emerge: workaround spawn problems for multiprocessing module

force fork mode, because spawn mode is currently broken.
spawn mode is used on macOS by default starting from Python 3.8

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/emerge | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/bin/emerge b/bin/emerge
index 8f1db61a6..006003819 100755
--- a/bin/emerge
+++ b/bin/emerge
@@ -2,6 +2,7 @@
 # Copyright 2006-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
+import multiprocessing
 import platform
 import signal
 import sys
@@ -44,6 +45,8 @@ try:
 	from _emerge.main import emerge_main
 
 	if __name__ == "__main__":
+		# PREFIX LOCAL force start method for python3.8 on darwin
+		multiprocessing.set_start_method('fork')
 		from portage.exception import IsADirectory, ParseError, \
 				PermissionDenied
 		portage.process.sanitize_fds()


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2021-01-04 10:42 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2021-01-04 10:42 UTC (permalink / raw
  To: gentoo-commits

commit:     662a036b107b8d923ace435565fcdff63c70a7e3
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Jan  4 10:38:40 2021 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Jan  4 10:38:40 2021 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=662a036b

Revert "emerge: workaround spawn problems for multiprocessing module"

This reverts commit 87cc6932b41bd9b612c53df10c68a2b93258b90d.

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/emerge | 3 ---
 1 file changed, 3 deletions(-)

diff --git a/bin/emerge b/bin/emerge
index 006003819..8f1db61a6 100755
--- a/bin/emerge
+++ b/bin/emerge
@@ -2,7 +2,6 @@
 # Copyright 2006-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-import multiprocessing
 import platform
 import signal
 import sys
@@ -45,8 +44,6 @@ try:
 	from _emerge.main import emerge_main
 
 	if __name__ == "__main__":
-		# PREFIX LOCAL force start method for python3.8 on darwin
-		multiprocessing.set_start_method('fork')
 		from portage.exception import IsADirectory, ParseError, \
 				PermissionDenied
 		portage.process.sanitize_fds()


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2021-07-06  7:10 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2021-07-06  7:10 UTC (permalink / raw
  To: gentoo-commits

commit:     2c3c1bfb3d2f45d67ec250a7d9514952f2685bb0
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Tue Jul  6 07:04:45 2021 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Tue Jul  6 07:04:45 2021 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=2c3c1bfb

ebuild-pyhelper: fix path to python executable

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/ebuild-pyhelper | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/bin/ebuild-pyhelper b/bin/ebuild-pyhelper
index d32bc6f6f..dbddd6e2a 100755
--- a/bin/ebuild-pyhelper
+++ b/bin/ebuild-pyhelper
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!@PORTAGE_BASH@
 # Copyright 2010-2021 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
@@ -14,7 +14,7 @@ cd "${PORTAGE_PYM_PATH}" || exit 1
 for path in "${PORTAGE_BIN_PATH}/${0##*/}"{.py,}; do
 	if [[ -x "${path}" ]]; then
 		PYTHONPATH=${PORTAGE_PYTHONPATH:-${PORTAGE_PYM_PATH}} \
-			exec "${PORTAGE_PYTHON:-/usr/bin/python}" "${path}" "$@"
+			exec "${PORTAGE_PYTHON:-@PREFIX_PORTAGE_PYTHON@/usr/bin/python}" "${path}" "$@"
 	fi
 done
 echo "File not found: ${path}" >&2


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2022-07-25 16:49 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2022-07-25 16:49 UTC (permalink / raw
  To: gentoo-commits

commit:     d17d765b1cc7615f053f970630a6ec3022f40dbb
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Jul 25 16:48:50 2022 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Jul 25 16:48:50 2022 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=d17d765b

bin/misc-functions: drop unused/stale install_mask function

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/misc-functions.sh | 46 +---------------------------------------------
 1 file changed, 1 insertion(+), 45 deletions(-)

diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index 8fcc23588..786c06c04 100755
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -667,50 +667,6 @@ postinst_qa_check() {
 	done < <(printf "%s\0" "${qa_checks[@]}" | LC_ALL=C sort -u -z)
 }
 
-install_mask() {
-	local root="$1"
-	shift
-	local install_mask="$*"
-
-	# We think of $install_mask as a space-separated list of
-	# globs. We don't want globbing in the "for" loop; that is, we
-	# want to keep the asterisks in the indivual entries.
-	local shopts=$-
-	set -o noglob
-	local no_inst
-	for no_inst in ${install_mask}; do
-		# Here, $no_inst is a single "entry" potentially
-		# containing a glob. From now on, we *do* want to
-		# expand it.
-		set +o noglob
-
-		# The standard case where $no_inst is something that
-		# the shell could expand on its own.
-		if [[ -e "${root}"/${no_inst} || -L "${root}"/${no_inst} ||
-			"${root}"/${no_inst} != $(echo "${root}"/${no_inst}) ]] ; then
-			__quiet_mode || einfo "Removing ${no_inst}"
-			rm -Rf "${root}"/${no_inst} >&/dev/null
-		fi
-
-		# We also want to allow the user to specify a "bare
-		# glob." For example, $no_inst="*.a" should prevent
-		# ALL files ending in ".a" from being installed,
-		# regardless of their location/depth. We achieve this
-		# by passing the pattern to `find`.
-		find "${root}" \( -path "${no_inst}" -or -name "${no_inst}" \) \
-			-print0 2> /dev/null \
-		| LC_ALL=C sort -z \
-		| while read -r -d ''; do
-			__quiet_mode || einfo "Removing /${REPLY#${root}}"
-			rm -Rf "${REPLY}" >&/dev/null
-		done
-
-	done
-	# set everything back the way we found it
-	set +o noglob
-	set -${shopts}
-}
-
 preinst_mask() {
 	# Remove man pages, info pages, docs if requested. This is
 	# implemented in bash in order to respect INSTALL_MASK settings
@@ -719,7 +675,7 @@ preinst_mask() {
 	for f in man info doc; do
 		if has no${f} ${FEATURES}; then
 		    # PREFIX LOCAL: use EPREFIX with path
-			INSTALL_MASK="${INSTALL_MASK} ${EPREFIX}/usr/share/${f}"
+			INSTALL_MASK+=" ${EPREFIX}/usr/share/${f}"
 		fi
 	done
 


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2022-07-25 16:55 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2022-07-25 16:55 UTC (permalink / raw
  To: gentoo-commits

commit:     d5bb2706b050431dcb6cbed8d154e4a570e10205
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Mon Jul 25 16:55:00 2022 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Mon Jul 25 16:55:00 2022 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=d5bb2706

bin/phase-functions.sh: make Prefix mod suitable for master

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/phase-functions.sh | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/bin/phase-functions.sh b/bin/phase-functions.sh
index 8e334c139..8b591d133 100644
--- a/bin/phase-functions.sh
+++ b/bin/phase-functions.sh
@@ -773,7 +773,9 @@ __dyn_help() {
 	fi
 	echo "  merge to    : ${ROOT}"
 	# PREFIX LOCAL: identify
-	echo "  offset      : ${EPREFIX}"
+	if [[ -n "${EPREFIX}" ]]; then
+		echo "  offset      : ${EPREFIX}"
+	fi
 	echo
 	if [[ -n "$USE" ]]; then
 		echo "Additionally, support for the following optional features will be enabled:"


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2022-07-28 18:23 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2022-07-28 18:23 UTC (permalink / raw
  To: gentoo-commits

commit:     ba2d9f2f34c90e49049dedf55555323a12c35ba9
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Thu Jul 28 18:23:07 2022 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Thu Jul 28 18:23:07 2022 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=ba2d9f2f

bin/phase-functions.sh: drop superseeded code

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/phase-functions.sh | 3 +--
 1 file changed, 1 insertion(+), 2 deletions(-)

diff --git a/bin/phase-functions.sh b/bin/phase-functions.sh
index fd20c7c0d..212b19fc1 100644
--- a/bin/phase-functions.sh
+++ b/bin/phase-functions.sh
@@ -31,8 +31,7 @@ PORTAGE_READONLY_VARS="D EBUILD EBUILD_PHASE EBUILD_PHASE_FUNC \
 	PORTAGE_TMPDIR PORTAGE_UPDATE_ENV PORTAGE_USERNAME \
 	PORTAGE_VERBOSE PORTAGE_WORKDIR_MODE PORTAGE_XATTR_EXCLUDE \
 	REPLACING_VERSIONS REPLACED_BY_VERSION T WORKDIR \
-	__PORTAGE_HELPER __PORTAGE_TEST_HARDLINK_LOCKS ED EROOT"
-    # PREFIX LOCAL: include ED EROOT (above)
+	__PORTAGE_HELPER __PORTAGE_TEST_HARDLINK_LOCKS"
 
 PORTAGE_SAVED_READONLY_VARS="A CATEGORY P PF PN PR PV PVR"
 


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2022-07-28 18:33 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2022-07-28 18:33 UTC (permalink / raw
  To: gentoo-commits

commit:     7aeca65f71a37d00d2c73d5ba5f583da014c0dec
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Thu Jul 28 18:31:22 2022 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Thu Jul 28 18:31:22 2022 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=7aeca65f

bin/phase-functions.sh: drop Prefix announce

I can't seem to figure out how to trigger this function at all, which
means, if it is possible to trigger afterall (not via ebuild command),
it will be via an obscure route that doesn't really matter whether or
not EPREFIX value is advertised.

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/phase-functions.sh | 4 ----
 1 file changed, 4 deletions(-)

diff --git a/bin/phase-functions.sh b/bin/phase-functions.sh
index 212b19fc1..8efd12f22 100644
--- a/bin/phase-functions.sh
+++ b/bin/phase-functions.sh
@@ -771,10 +771,6 @@ __dyn_help() {
 		echo "production (stripped)"
 	fi
 	echo "  merge to    : ${ROOT}"
-	# PREFIX LOCAL: identify
-	if [[ -n "${EPREFIX}" ]]; then
-		echo "  offset      : ${EPREFIX}"
-	fi
 	echo
 	if [[ -n "$USE" ]]; then
 		echo "Additionally, support for the following optional features will be enabled:"


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2022-08-16 17:04 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2022-08-16 17:04 UTC (permalink / raw
  To: gentoo-commits

commit:     32ed39b3ffa37c79a813ad51f4afa0e4264529f3
Author:     Etienne Buira <etienne.buira <AT> free <DOT> fr>
AuthorDate: Tue Aug 16 17:03:22 2022 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Tue Aug 16 17:03:22 2022 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=32ed39b3

bugfix: do not try to install removed readpecoff

fixes: e5c884abfc5a00fad25c7086bc987f003f0b5473

Signed-off-by: Fabian Groffen <grobian <AT> gentoo.org>

 bin/Makefile.in | 1 -
 1 file changed, 1 deletion(-)

diff --git a/bin/Makefile.in b/bin/Makefile.in
index afff11dfb..d91a635e8 100644
--- a/bin/Makefile.in
+++ b/bin/Makefile.in
@@ -32,7 +32,6 @@ usr_sbinprogs = \
 	env-update \
 	etc-update \
 	fixpackages \
-	readpecoff \
 	regenworld
 
 all:


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2023-07-03 20:19 Sam James
  0 siblings, 0 replies; 47+ messages in thread
From: Sam James @ 2023-07-03 20:19 UTC (permalink / raw
  To: gentoo-commits

commit:     65b4a7839d11d6f2be0f0811bce8f66f06e40ca7
Author:     Kerin Millar <kfm <AT> plushkava <DOT> net>
AuthorDate: Sun Jun 25 20:16:51 2023 +0000
Commit:     Sam James <sam <AT> gentoo <DOT> org>
CommitDate: Mon Jul  3 20:19:31 2023 +0000
URL:        https://gitweb.gentoo.org/proj/portage.git/commit/?id=65b4a783

bin/save-ebuild-env.sh: refrain from using the compgen builtin

For the compgen builtin to be available requires that bash be compiled
with --enable-readline. Rather than rely on compgen to generate a list
of function names, parse their names out of declare -F instead. This
eliminates an unnecessary divergence from the master branch.

Specify -v for the following unset command, so that bash is coerced into
unsetting only variables, as is intended.

Expand the applicable variable names with "${!___@}". Owing to the
constraints placed on identifiers, it's not particularly important that
it be done this way, but I think it better expresses the intent.

Signed-off-by: Kerin Millar <kfm <AT> plushkava.net>
Bug: https://bugs.gentoo.org/909148
Signed-off-by: Sam James <sam <AT> gentoo.org>

 bin/save-ebuild-env.sh | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/bin/save-ebuild-env.sh b/bin/save-ebuild-env.sh
index 36eedc7fa..294cab255 100755
--- a/bin/save-ebuild-env.sh
+++ b/bin/save-ebuild-env.sh
@@ -82,13 +82,13 @@ __save_ebuild_env() {
 
 	___eapi_has_usex && unset -f usex
 
-	# BEGIN PREFIX LOCAL: compgen is not compiled in during bootstrap
-	if type compgen >& /dev/null ; then
-		# Clear out the triple underscore namespace as it is reserved by the PM.
-		unset -f $(compgen -A function ___)
-		unset ${!___*}
-	fi
-	# END PREFIX LOCAL
+	# Clear out the triple underscore namespace as it is reserved by the PM.
+	while IFS=' ' read -r _ _ REPLY; do
+		if [[ ${REPLY} == ___* ]]; then
+			unset -f "${REPLY}"
+		fi
+	done < <(declare -F)
+	unset -v REPLY "${!___@}"
 
 	# portage config variables and variables set directly by portage
 	unset ACCEPT_LICENSE BUILD_PREFIX COLS \


^ permalink raw reply related	[flat|nested] 47+ messages in thread

end of thread, other threads:[~2023-07-03 20:19 UTC | newest]

Thread overview: 47+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2013-08-16 12:50 [gentoo-commits] proj/portage:prefix commit in: bin/ Fabian Groffen
  -- strict thread matches above, loose matches on Subject: below --
2023-07-03 20:19 Sam James
2022-08-16 17:04 Fabian Groffen
2022-07-28 18:33 Fabian Groffen
2022-07-28 18:23 Fabian Groffen
2022-07-25 16:55 Fabian Groffen
2022-07-25 16:49 Fabian Groffen
2021-07-06  7:10 Fabian Groffen
2021-01-04 10:42 Fabian Groffen
2020-12-07 16:49 Fabian Groffen
2020-11-28 19:47 Fabian Groffen
2020-11-28 19:37 Fabian Groffen
2019-07-01 13:11 Fabian Groffen
2019-06-03 19:21 Fabian Groffen
2019-06-03 19:00 Fabian Groffen
2018-12-23 19:55 Fabian Groffen
2018-12-06 12:46 Fabian Groffen
2017-03-24  7:43 Fabian Groffen
2017-03-23 15:25 Fabian Groffen
2014-10-24 19:14 Fabian Groffen
2014-10-02 18:47 Fabian Groffen
2014-09-30 16:04 Fabian Groffen
2013-10-06 19:01 Fabian Groffen
2013-09-18 18:34 Fabian Groffen
2013-09-18 18:34 Fabian Groffen
2013-09-12  7:32 Fabian Groffen
2013-03-31 10:03 Fabian Groffen
2013-03-24  8:45 Fabian Groffen
2013-03-24  8:34 Fabian Groffen
2013-01-10 21:13 Fabian Groffen
2012-12-26 15:06 Fabian Groffen
2012-12-02 12:58 Fabian Groffen
2012-10-22 17:57 Fabian Groffen
2012-09-30 12:12 Fabian Groffen
2012-09-12 18:26 Fabian Groffen
2012-08-12  7:44 Fabian Groffen
2012-07-08 17:25 Fabian Groffen
2012-04-03 18:09 Fabian Groffen
2011-12-10 13:14 Fabian Groffen
2011-12-09 20:36 Fabian Groffen
2011-12-03 16:49 Fabian Groffen
2011-12-03 15:22 Fabian Groffen
2011-09-23 18:33 Fabian Groffen
2011-09-23 18:23 Fabian Groffen
2011-09-13 18:45 Fabian Groffen
2011-08-20 18:35 Fabian Groffen
2011-04-24 17:20 Fabian Groffen

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/bin/misc-functions.sh b/bin/misc-functions.sh
index d46ab06..8c6a126 100644
--- a/bin/misc-functions.sh
+++ b/bin/misc-functions.sh
@@ -949,8 +949,9 @@ install_qa_check_prefix() {
 			fi
 			continue
 		fi
-		# unprefixed shebang, is the script directly in $PATH?
-		if [[ ":${PATH}:" == *":${fp}:"* ]] ; then
+		# unprefixed shebang, is the script directly in $PATH or an init
+		# script?
+		if [[ ":${PATH}:${EPREFIX}/etc/init.d:" == *":${fp}:"* ]] ; then
 			if [[ -e ${EROOT}${line[0]} || -e ${ED}${line[0]} ]] ; then
 				# is it unprefixed, but we can just fix it because a
 				# prefixed variant exists


^ permalink raw reply related	[flat|nested] 47+ messages in thread

* [gentoo-commits] proj/portage:prefix commit in: bin/
@ 2012-09-30 12:12 Fabian Groffen
  0 siblings, 0 replies; 47+ messages in thread
From: Fabian Groffen @ 2012-09-30 12:12 UTC (permalink / raw
  To: gentoo-commits

commit:     1c3c3b802014ac6356af09d149aaaffce6c14dc3
Author:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
AuthorDate: Sun Sep 30 12:11:25 2012 +0000
Commit:     Fabian Groffen <grobian <AT> gentoo <DOT> org>
CommitDate: Sun Sep 30 12:11:25 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=1c3c3b80

debug-print: use PORTAGE_GROUP iso hardcoded portage

With the new chown wrapper we get spammed to death by each and every
ebuild due to us chgrp-ing to a non-existant group.  Use the once
determined for Portage at configure time instead.

---
 bin/ebuild.sh |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)
